========
skymatch
========

The ``skymatch`` function performs the actual sky
matching operations on the input image data models.

.. currentmodule:: romancal.skymatch.skymatch

.. automodule:: romancal.skymatch.skymatch
   :members:
   :undoc-members:
